Support
-------

Questions can be asked on `GitHub Discussions <https://github.com/asreview/asreview/discussions>`__. For bug reports and feature requests, please submit an issue on `GitHub <https://github.com/asreview/asreview/issues/new/choose>`__.

Donate
~~~~~~

The ASReview software is Free and Open Source Software (FOSS). To support the
development, you can donate on the `ASReview donation page
<https://asreview.ai/donate/>`_. Even small donations are highly appreciated!


Collaborate
~~~~~~~~~~~

If you are interested in (scientific) collaboration, `contact
Prof. Dr. Rens van de Schoot <https://www.rensvandeschoot.com/contact/>`_ or send an email to asreview@uu.nl.


Contribute
~~~~~~~~~~

How do you go from user to contributor? There are many ways to join in, and it might be less complicated than you expect. In a `blogpost <https://asreview.nl/blog/open-source-and-research/>`_, we list some easy examples for first-time contributors, for example sharing your experiences or answering user questions on the `Discussion platform <https://github.com/asreview/asreview/discussions>`_.

Specific instructions for code-contributing are available on `Github <https://github.com/asreview/asreview/blob/master/CONTRIBUTING.md>`_ as well as instructions for `developers <https://github.com/asreview/asreview/blob/master/DEVELOPMENT.md>`_.


.. note::

	All contributions, small or large, are very much appreciated!
